==> tabular-data-widgetx-tdx-source-1.2.0-20140620.150913-35-sources.jar: org/gcube/portlets/user/tdwx/datasource/td/map/ColumnDefinitionBuilder.java <==
package org.gcube.portlets.user.tdwx.datasource.td.map;

import java.util.List;

import org.gcube.data.analysis.tabulardata.metadata.NoSuchMetadataException;
import org.gcube.data.analysis.tabulardata.model.column.Column;
import org.gcube.data.analysis.tabulardata.model.column.ColumnType;
import org.gcube.data.analysis.tabulardata.model.datatype.DataType;
import org.gcube.data.analysis.tabulardata.model.metadata.column.DataLocaleMetadata;
import org.gcube.data.analysis.tabulardata.model.metadata.column.ValidationReferencesMetadata;
import org.gcube.data.analysis.tabulardata.model.metadata.column.ViewColumnMetadata;
import org.gcube.data.analysis.tabulardata.model.metadata.common.LocalizedText;
import org.gcube.data.analysis.tabulardata.model.metadata.common.NamesMetadata;
import org.gcube.data.analysis.tabulardata.model.metadata.common.Validation;
import org.gcube.data.analysis.tabulardata.model.metadata.common.ValidationsMetadata;
import org.gcube.data.analysis.tabulardata.model.relationship.ColumnRelationship;

import org.gcube.portlets.user.td.widgetcommonevent.shared.tr.column.RelationshipData;
import org.gcube.portlets.user.tdwx.shared.model.ColumnDefinition;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class ColumnDefinitionBuilder {
	protected Logger logger = LoggerFactory
			.getLogger(ColumnDefinitionBuilder.class);

	protected Column serviceColumn;
	protected String tooltipMessage;
	protected String columnName;
	protected String columnLocalId;
	protected boolean visible;
	protected boolean editable;
	protected org.gcube.portlets.user.tdwx.shared.model.ColumnType type;
	protected String columnLabel;
	protected String locale;
	protected int ordinalPosition;

	protected RelationshipData relationshipData;
	
	protected String sourceTableDimensionColumnId;
	protected String targetTableColumnId;
	protected long targetTableId;
	protected boolean viewColumn;

	public ColumnDefinitionBuilder(Column serviceColumn, int ordinalPosition) {
		this.serviceColumn = serviceColumn;
		this.ordinalPosition = ordinalPosition;
		
		visible = true;
		type = org.gcube.portlets.user.tdwx.shared.model.ColumnType.USER;
		editable=true;
		ColumnType ct = serviceColumn.getColumnType();
		if (ColumnTypeMap.isIdColumnType(ct)) {
			columnLabel = "Id";
			visible = false;
			editable=false;
			type = org.gcube.portlets.user.tdwx.shared.model.ColumnType.COLUMNID;
		} else {
			if (ColumnTypeMap.isValidationColumnType(ct)) {
				type = org.gcube.portlets.user.tdwx.shared.model.ColumnType.VALIDATION;
				editable=false;
			
			}
			
			if (ColumnTypeMap.isTimeDimensionColumnType(ct)) {
				type = org.gcube.portlets.user.tdwx.shared.model.ColumnType.TIMEDIMENSION;
				visible=false;
				retrieveRelationship();
			}
			
			if (ColumnTypeMap.isDimensionColumnType(ct)) {
				type = org.gcube.portlets.user.tdwx.shared.model.ColumnType.DIMENSION;
				visible=false;
				retrieveRelationship();
			
			}
			
			if(serviceColumn.contains(ViewColumnMetadata.class)){
				ViewColumnMetadata viewMetadata=serviceColumn.getMetadata(ViewColumnMetadata.class);
				logger.debug("ViewColumnMetadata: "+viewMetadata.toString());
				viewColumn=true;
				sourceTableDimensionColumnId=viewMetadata.getSourceTableDimensionColumnId().getValue();
				targetTableColumnId=viewMetadata.getTargetTableColumnId().getValue();
				targetTableId=viewMetadata.getTargetTableId().getValue();
				type = org.gcube.portlets.user.tdwx.shared.model.ColumnType.VIEWCOLUMN;
				visible=false;
			} else {
				viewColumn=false;
			}
			

			NamesMetadata labelsMetadata = null;
			try {
				labelsMetadata = serviceColumn
						.getMetadata(NamesMetadata.class);
			} catch (NoSuchMetadataException e) {
				logger.debug("labelMetadata: NoSuchMetadataException "
						+ e.getLocalizedMessage());
			}

			if (labelsMetadata == null) {
				columnLabel = "nolabel";
			} else {
				LocalizedText cl = null;
				cl = labelsMetadata.getTextWithLocale("en");
				if (cl == null) {
						columnLabel = "nolabel";
						logger.debug("ColumnLabel no label in en");					
				} else {
					columnLabel = cl.getValue();
					if(columnLabel==null|| columnLabel.isEmpty()){
						columnLabel="nolabel";
					}
				}
			}
			
			DataLocaleMetadata dataLocaleMetadata = null;
			try {
				dataLocaleMetadata = serviceColumn.getMetadata(DataLocaleMetadata.class);
			} catch (NoSuchMetadataException e) {
				logger.debug("DataLocaleMetadata: NoSuchMetadataException "
						+ e.getLocalizedMessage());
			}
			
			if (dataLocaleMetadata == null) {
				logger.debug("No DataLocaleMetadata");
				locale="";
			} else {
				locale=dataLocaleMetadata.getLocale();
			}
			

		}

	}
	
	protected void retrieveRelationship(){
		ColumnRelationship rel = serviceColumn.getRelationship();
		if (rel != null) {
			relationshipData = new RelationshipData(rel
					.getTargetTableId().getValue(), rel
					.getTargetColumnId().getValue());
			
			
		}
	}
	
	public boolean isVisible() {
		return visible;
	}

	public org.gcube.portlets.user.tdwx.shared.model.ColumnType getType() {
		return type;
	}

	public String getColumnLabel() {
		return columnLabel;
	}

	public String getColumnName() {
		columnName = serviceColumn.getName();
		return columnName;
	}

	public String getColumnLocalId() {
		columnLocalId = serviceColumn.getLocalId().getValue();
		return columnLocalId;
	}

	public ValidationReferencesMetadata getValidationReferencesMetadata() {
		ValidationReferencesMetadata refs = null;
		try {
			refs = serviceColumn
					.getMetadata(ValidationReferencesMetadata.class);
		} catch (NoSuchMetadataException e) {
			logger.debug("ValidationReferencesMetadata: NoSuchMetadataException "
					+ e.getLocalizedMessage());
		}

		return refs;
	}
	

	
	public String getTooltipMessage() {
		String valids = new String();
		ValidationsMetadata val=null;
		try {
			val = serviceColumn
					.getMetadata(ValidationsMetadata.class);
		} catch (NoSuchMetadataException e) {
			logger.debug("No validatationsMetadata present: "
					+ e.getLocalizedMessage());
		}

		if (val != null) {
			List<Validation> listValidationsMetadata = ((ValidationsMetadata) val)
					.getValidations();
			for (Validation validation : listValidationsMetadata) {
				valids.concat(validation.getDescription() + "\n");
			}
		}
		tooltipMessage = valids;

		return tooltipMessage;
	}

	public ColumnDefinition build() {
		ColumnDefinition columnDefinition = new ColumnDefinition(
				getColumnName(), getColumnLocalId(), getColumnLabel());
		columnDefinition.setLocale(locale);
		
		columnDefinition.setRelationshipData(relationshipData);
		columnDefinition.setViewColumn(viewColumn);
		columnDefinition.setTargetTableId(targetTableId);
		columnDefinition.setTargetTableColumnId(targetTableColumnId);
		columnDefinition.setSourceTableDimensionColumnId(sourceTableDimensionColumnId);
		
		DataType dataType = serviceColumn.getDataType();
		columnDefinition.setVisible(visible);
		columnDefinition.setEditable(editable);
		columnDefinition.setValueType(DataTypeMap.getValueType(dataType));
		columnDefinition.setType(getType());
		columnDefinition.setPosition(ordinalPosition);
		columnDefinition.setTooltipMessage(getTooltipMessage());
		columnDefinition.setColumnTypeName(serviceColumn.getColumnType()
				.getName());
		columnDefinition.setColumnDataType(serviceColumn.getDataType()
				.getName());
		columnDefinition.setWidth(100);
		return columnDefinition;
	}

}

==> tabular-data-widgetx-tdx-source-1.3.0-20140903.135025-27-sources.jar: org/gcube/portlets/user/tdwx/datasource/td/map/ColumnDefinitionBuilder.java <==
package org.gcube.portlets.user.tdwx.datasource.td.map;

import java.util.List;

import org.gcube.data.analysis.tabulardata.metadata.NoSuchMetadataException;
import org.gcube.data.analysis.tabulardata.model.column.Column;
import org.gcube.data.analysis.tabulardata.model.column.ColumnType;
import org.gcube.data.analysis.tabulardata.model.datatype.DataType;
import org.gcube.data.analysis.tabulardata.model.metadata.column.DataLocaleMetadata;
import org.gcube.data.analysis.tabulardata.model.metadata.column.ValidationReferencesMetadata;
import org.gcube.data.analysis.tabulardata.model.metadata.column.ViewColumnMetadata;
import org.gcube.data.analysis.tabulardata.model.metadata.common.LocalizedText;
import org.gcube.data.analysis.tabulardata.model.metadata.common.NamesMetadata;
import org.gcube.data.analysis.tabulardata.model.metadata.common.Validation;
import org.gcube.data.analysis.tabulardata.model.metadata.common.ValidationsMetadata;
import org.gcube.data.analysis.tabulardata.model.relationship.ColumnRelationship;

import org.gcube.portlets.user.td.widgetcommonevent.shared.tr.column.RelationshipData;
import org.gcube.portlets.user.tdwx.server.datasource.DataSourceXException;
import org.gcube.portlets.user.tdwx.shared.model.ColumnDefinition;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class ColumnDefinitionBuilder {
	protected Logger logger = LoggerFactory
			.getLogger(ColumnDefinitionBuilder.class);

	protected Column serviceColumn;
	protected String tooltipMessage;
	protected String columnName;
	protected String columnLocalId;
	protected boolean visible;
	protected boolean editable;
	protected org.gcube.portlets.user.tdwx.shared.model.ColumnType type;
	protected String columnLabel;
	protected String locale;
	protected int ordinalPosition;

	protected RelationshipData relationshipData;
	
	protected String sourceTableDimensionColumnId;
	protected String targetTableColumnId;
	protected long targetTableId;
	protected boolean viewColumn;

	public ColumnDefinitionBuilder(Column serviceColumn, int ordinalPosition) throws DataSourceXException {
		this.serviceColumn = serviceColumn;
		this.ordinalPosition = ordinalPosition;
		
		visible = true;
		type = org.gcube.portlets.user.tdwx.shared.model.ColumnType.USER;
		editable=true;
		ColumnType ct = serviceColumn.getColumnType();
		if (ColumnTypeMap.isIdColumnType(ct)) {
			columnLabel = "Id";
			visible = false;
			editable=false;
			type = org.gcube.portlets.user.tdwx.shared.model.ColumnType.COLUMNID;
		} else {
			if (ColumnTypeMap.isValidationColumnType(ct)) {
				type = org.gcube.portlets.user.tdwx.shared.model.ColumnType.VALIDATION;
				editable=false;
			
			}
			
			if (ColumnTypeMap.isTimeDimensionColumnType(ct)) {
				type = org.gcube.portlets.user.tdwx.shared.model.ColumnType.TIMEDIMENSION;
				visible=false;
				retrieveRelationship();
			}
			
			if (ColumnTypeMap.isDimensionColumnType(ct)) {
				type = org.gcube.portlets.user.tdwx.shared.model.ColumnType.DIMENSION;
				visible=false;
				retrieveRelationship();
			
			}
			
			if(serviceColumn.contains(ViewColumnMetadata.class)){
				ViewColumnMetadata viewMetadata=serviceColumn.getMetadata(ViewColumnMetadata.class);
				logger.debug("ViewColumnMetadata: "+viewMetadata.toString());
				viewColumn=true;
				sourceTableDimensionColumnId=viewMetadata.getSourceTableDimensionColumnId().getValue();
				targetTableColumnId=viewMetadata.getTargetTableColumnId().getValue();
				targetTableId=viewMetadata.getTargetTableId().getValue();
				type = org.gcube.portlets.user.tdwx.shared.model.ColumnType.VIEWCOLUMN;
				visible=false;
			} else {
				viewColumn=false;
			}
			

			NamesMetadata labelsMetadata = null;
			try {
				labelsMetadata = serviceColumn
						.getMetadata(NamesMetadata.class);
			} catch (NoSuchMetadataException e) {
				logger.debug("labelMetadata: NoSuchMetadataException "
						+ e.getLocalizedMessage());
			}

			if (labelsMetadata == null) {
				columnLabel = "nolabel";
			} else {
				LocalizedText cl = null;
				cl = labelsMetadata.getTextWithLocale("en");
				if (cl == null) {
						columnLabel = "nolabel";
						logger.debug("ColumnLabel no label in en");					
				} else {
					columnLabel = cl.getValue();
					if(columnLabel==null|| columnLabel.isEmpty()){
						columnLabel="nolabel";
					}
				}
			}
			
			DataLocaleMetadata dataLocaleMetadata = null;
			try {
				dataLocaleMetadata = serviceColumn.getMetadata(DataLocaleMetadata.class);
			} catch (NoSuchMetadataException e) {
				logger.debug("DataLocaleMetadata: NoSuchMetadataException "
						+ e.getLocalizedMessage());
			}
			
			if (dataLocaleMetadata == null) {
				logger.debug("No DataLocaleMetadata");
				locale="";
			} else {
				locale=dataLocaleMetadata.getLocale();
			}
			

		}

	}
	
	protected void retrieveRelationship() throws DataSourceXException {
		ColumnRelationship rel = serviceColumn.getRelationship();
		if (rel != null) {
			relationshipData = new RelationshipData(rel
					.getTargetTableId().getValue(), rel
					.getTargetColumnId().getValue());	
		} else {
			logger.error("No valid relationship for column: "+serviceColumn.toString());
			throw new  DataSourceXException("Column  has not valid relationship");
		}
	}
	
	public boolean isVisible() {
		return visible;
	}

	public org.gcube.portlets.user.tdwx.shared.model.ColumnType getType() {
		return type;
	}

	public String getColumnLabel() {
		return columnLabel;
	}

	public String getColumnName() {
		columnName = serviceColumn.getName();
		return columnName;
	}

	public String getColumnLocalId() {
		columnLocalId = serviceColumn.getLocalId().getValue();
		return columnLocalId;
	}

	public ValidationReferencesMetadata getValidationReferencesMetadata() {
		ValidationReferencesMetadata refs = null;
		try {
			refs = serviceColumn
					.getMetadata(ValidationReferencesMetadata.class);
		} catch (NoSuchMetadataException e) {
			logger.debug("ValidationReferencesMetadata: NoSuchMetadataException "
					+ e.getLocalizedMessage());
		}

		return refs;
	}
	

	
	public String getTooltipMessage() {
		String valids = new String();
		ValidationsMetadata val=null;
		try {
			val = serviceColumn
					.getMetadata(ValidationsMetadata.class);
		} catch (NoSuchMetadataException e) {
			logger.debug("No validatationsMetadata present: "
					+ e.getLocalizedMessage());
		}

		if (val != null) {
			List<Validation> listValidationsMetadata = ((ValidationsMetadata) val)
					.getValidations();
			for (Validation validation : listValidationsMetadata) {
				valids.concat(validation.getDescription() + "\n");
			}
		}
		tooltipMessage = valids;

		return tooltipMessage;
	}

	public ColumnDefinition build() {
		ColumnDefinition columnDefinition = new ColumnDefinition(
				getColumnName(), getColumnLocalId(), getColumnLabel());
		columnDefinition.setLocale(locale);
		
		columnDefinition.setRelationshipData(relationshipData);
		columnDefinition.setViewColumn(viewColumn);
		columnDefinition.setTargetTableId(targetTableId);
		columnDefinition.setTargetTableColumnId(targetTableColumnId);
		columnDefinition.setSourceTableDimensionColumnId(sourceTableDimensionColumnId);
		
		DataType dataType = serviceColumn.getDataType();
		columnDefinition.setVisible(visible);
		columnDefinition.setEditable(editable);
		columnDefinition.setValueType(DataTypeMap.getValueType(dataType));
		columnDefinition.setType(getType());
		columnDefinition.setPosition(ordinalPosition);
		columnDefinition.setTooltipMessage(getTooltipMessage());
		columnDefinition.setColumnTypeName(serviceColumn.getColumnType()
				.getName());
		columnDefinition.setColumnDataType(serviceColumn.getDataType()
				.getName());
		columnDefinition.setWidth(100);
		return columnDefinition;
	}

}
